@@ -1,4 +1,4 @@
-"""jc - JSON CLI output utility `iw DEV scan` command output parser
+"""jc - JSON CLI output utility `iw dev <device> scan` command output parser
 
 This parser is considered beta quality. Not all fields are parsed.
 
@@ -139,7 +139,7 @@ def process(proc_data):
     Returns:
 
         List of Dictionaries. Structured data with the following schema:
-        ]
+        [
           {
             "foo":     string/integer/float,         # best guess based on value
             "bar":     string/integer/float,
