@@ -1,5 +1,7 @@
 """jc - JSON CLI output utility `last` and `lastb` command output parser
 
+Supports -w and -F options.
+
 Usage (cli):
 
     $ last | jc --last
@@ -19,30 +21,36 @@ Compatibility:
 
 Examples:
 
-    $ last | jc --last -p
+    $ last -F | jc --last -p
     [
       {
         "user": "kbrazil",
         "tty": "ttys002",
         "hostname": null,
-        "login": "Thu Feb 27 14:31",
+        "login": "Mon Dec 28 17:24:10 2020",
         "logout": "still logged in"
       },
       {
         "user": "kbrazil",
         "tty": "ttys003",
         "hostname": null,
-        "login": "Thu Feb 27 10:38",
-        "logout": "10:38",
-        "duration": "00:00"
+        "login": "Mon Dec 28 17:24:10 2020",
+        "logout": "Mon Dec 28 17:25:01 2020",
+        "duration": "00:00",
+        "login_epoch": 1565891826,
+        "logout_epoch": 1565895404,
+        "duration_seconds": 3578
       },
       {
         "user": "kbrazil",
         "tty": "ttys003",
         "hostname": null,
-        "login": "Thu Feb 27 10:18",
-        "logout": "10:18",
-        "duration": "00:00"
+        "login": "Mon Dec 28 17:24:10 2020",
+        "logout": "Mon Dec 28 17:25:01 2020",
+        "duration": "00:00",
+        "login_epoch": 1565891826,
+        "logout_epoch": 1565895404,
+        "duration_seconds": 3578
       },
       ...
     ]
@@ -77,15 +85,16 @@ Examples:
 
 """
 import re
+from datetime import datetime
 import jc.utils
 
 
 class info():
-    version = '1.3'
+    version = '1.4'
     description = 'last and lastb command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-    # details = 'enter any other details here'
+    details = 'Enhancements by https://github.com/zerolagtime'
 
     # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'aix', 'freebsd']
@@ -101,20 +110,23 @@ def process(proc_data):
 
     Parameters:
 
-        proc_data:   (dictionary) raw structured data to process
+        proc_data:   (List of Dictionaries) raw structured data to process
 
     Returns:
 
-        List of dictionaries. Structured data with the following schema:
+        List of Dictionaries. Structured data with the following schema:
 
         [
           {
-            "user":       string,
-            "tty":        string,
-            "hostname":   string,
-            "login":      string,
-            "logout":     string,
-            "duration":   string
+            "user":             string,
+            "tty":              string,
+            "hostname":         string,
+            "login":            string,
+            "logout":           string,
+            "duration":         string,
+            "login_epoch":      integer,   # available with last -F option
+            "logout_epoch":     integer,   # available with last -F option
+            "duration_seconds": integer    # available with last -F option
           }
         ]
     """
@@ -131,12 +143,29 @@ def process(proc_data):
         if 'hostname' in entry and entry['hostname'] == '-':
             entry['hostname'] = None
 
+        if 'hostname' in entry and entry['hostname'] is not None and entry['hostname'][0] == ":":
+            entry['hostname'] = f'CONSOLE{entry["hostname"]}'
+
         if 'logout' in entry and entry['logout'] == 'still_logged_in':
             entry['logout'] = 'still logged in'
 
         if 'logout' in entry and entry['logout'] == 'gone_-_no_logout':
             entry['logout'] = 'gone - no logout'
 
+        if 'login' in entry and re.match(r'.*\d\d:\d\d:\d\d \d\d\d\d.*',entry['login']):
+            entry['login_epoch'] = int(datetime.strptime(entry['login'], '%a %b %d %H:%M:%S %Y').strftime('%s'))
+
+        if 'logout' in entry and re.match(r'.*\d\d:\d\d:\d\d \d\d\d\d.*',entry['logout']):
+            entry['logout_epoch'] = int(datetime.strptime(entry['logout'], '%a %b %d %H:%M:%S %Y').strftime('%s'))
+
+        if 'login_epoch' in entry and 'logout_epoch' in entry:
+            entry['duration_seconds'] = int(entry['logout_epoch']) - int(entry['login_epoch'])
+
+        if 'duration' in entry and re.match(r'^\d+\+', entry['duration']):
+            m = re.match(r'^(?P<days>\d+)\+(?P<hours>\d\d):(?P<minutes>\d\d)', entry['duration'])
+            days, hours, minutes = m.groups()
+            entry['duration'] = f'{int(days)*24 + int(hours)}:{minutes}'
+
     return proc_data
 
 
@@ -152,7 +181,7 @@ def parse(data, raw=False, quiet=False):
 
     Returns:
 
-        List of dictionaries. Raw or processed structured data.
+        List of Dictionaries. Raw or processed structured data.
     """
     if not quiet:
         jc.utils.compatibility(__name__, info.compatible)
@@ -187,13 +216,34 @@ def parse(data, raw=False, quiet=False):
             output_line['user'] = linedata[0]
             output_line['tty'] = linedata[1]
             output_line['hostname'] = linedata[2]
-            output_line['login'] = ' '.join(linedata[3:7])
 
-            if len(linedata) > 8:
-                output_line['logout'] = linedata[8]
+            # last -F support
+            if re.match(r'\d\d:\d\d:\d\d \d\d\d\d', ' '.join(linedata[6:8])):
+                output_line['login'] = ' '.join(linedata[3:8])
 
-            if len(linedata) > 9:
-                output_line['duration'] = linedata[9].replace('(', '').replace(')', '')
+                if len(linedata) > 9 and linedata[9] != 'crash' and linedata[9] != 'down':
+                    output_line['logout'] = ' '.join(linedata[9:14])
+
+                if len(linedata) > 9 and (linedata[9] == 'crash' or linedata[9] == 'down'):
+                    output_line['logout'] = linedata[9]
+                    # add more items to the list to line up duration
+                    linedata.insert(10, '-')
+                    linedata.insert(10, '-')
+                    linedata.insert(10, '-')
+                    linedata.insert(10, '-')
+
+                if len(linedata) > 14:
+                    output_line['duration'] = linedata[14].replace('(', '').replace(')', '')
+
+            # normal last support
+            else:
+                output_line['login'] = ' '.join(linedata[3:7])
+
+                if len(linedata) > 8:
+                    output_line['logout'] = linedata[8]
+
+                if len(linedata) > 9:
+                    output_line['duration'] = linedata[9].replace('(', '').replace(')', '')
 
             raw_output.append(output_line)
 
