@@ -37,6 +37,9 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/osx-10.14.6/arp-a2.out'), 'r', encoding='utf-8') as f:
             self.osx_10_14_6_arp_a2 = f.read()
 
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/freebsd12/arp-a.out'), 'r', encoding='utf-8') as f:
+            self.freebsd_arp_a = f.read()
+
         # output
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/arp.json'), 'r', encoding='utf-8') as f:
             self.centos_7_7_arp_json = json.loads(f.read())
@@ -65,6 +68,15 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/osx-10.14.6/arp-a2.json'), 'r', encoding='utf-8') as f:
             self.osx_10_14_6_arp_a2_json = json.loads(f.read())
 
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/freebsd12/arp-a.json'), 'r', encoding='utf-8') as f:
+            self.freebsd12_arp_a_json = json.loads(f.read())
+
+    def test_arp_nodata(self):
+        """
+        Test 'arp' with no data
+        """
+        self.assertEqual(jc.parsers.arp.parse('', quiet=True), [])
+
     def test_arp_centos_7_7(self):
         """
         Test 'arp' on Centos 7.7
@@ -119,6 +131,12 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.arp.parse(self.osx_10_14_6_arp_a2, quiet=True), self.osx_10_14_6_arp_a2_json)
 
+    def test_arp_a_freebsd12(self):
+        """
+        Test 'arp -a' on FreeBSD12
+        """
+        self.assertEqual(jc.parsers.arp.parse(self.freebsd_arp_a, quiet=True), self.freebsd12_arp_a_json)
+
 
 if __name__ == '__main__':
     unittest.main()
