@@ -17,6 +17,12 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/crontab.json'), 'r', encoding='utf-8') as f:
             self.centos_7_7_crontab_json = json.loads(f.read())
 
+    def test_crontab_nodata(self):
+        """
+        Test 'crontab' with no data
+        """
+        self.assertEqual(jc.parsers.crontab.parse('', quiet=True), {})
+
     def test_crontab_centos_7_7(self):
         """
         Test 'crontab' on Centos 7.7
