@@ -37,6 +37,15 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/freebsd12/last.out'), 'r', encoding='utf-8') as f:
             self.freebsd12_last = f.read()
 
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-20.04/last-F.out'), 'r', encoding='utf-8') as f:
+            self.ubuntu_20_4_last_F = f.read()
+
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/last-crash.out'), 'r', encoding='utf-8') as f:
+            self.centos_7_7_last_crash = f.read()
+
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/last-wF.out'), 'r', encoding='utf-8') as f:
+            self.centos_7_7_last_wF = f.read()
+
         # output
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/last.json'), 'r', encoding='utf-8') as f:
             self.centos_7_7_last_json = json.loads(f.read())
@@ -65,6 +74,15 @@ class MyTests(unittest.TestCase):
         with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/freebsd12/last.json'), 'r', encoding='utf-8') as f:
             self.freebsd12_last_json = json.loads(f.read())
 
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-20.04/last-F.json'), 'r', encoding='utf-8') as f:
+            self.ubuntu_20_4_last_F_json = json.loads(f.read())
+
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/last-crash.json'), 'r', encoding='utf-8') as f:
+            self.centos_7_7_last_crash_json = json.loads(f.read())
+
+        with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/last-wF.json'), 'r', encoding='utf-8') as f:
+            self.centos_7_7_last_wF_json = json.loads(f.read())
+
     def test_last_nodata(self):
         """
         Test plain 'last' with no data
@@ -113,6 +131,13 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.last.parse(self.ubuntu_18_4_last_w, quiet=True), self.ubuntu_18_4_last_w_json)
 
+    # Run this test locally only since environment differences can cause test failures
+    # def test_last_F_ubuntu_20_4(self):
+    #     """
+    #     Test 'last -F' on Ubuntu 20.4
+    #     """
+    #     self.assertEqual(jc.parsers.last.parse(self.ubuntu_20_4_last_F, quiet=True), self.ubuntu_20_4_last_F_json)
+
     def test_last_fedora32(self):
         """
         Test plain 'last' on Fedora32
@@ -125,6 +150,18 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.last.parse(self.freebsd12_last, quiet=True), self.freebsd12_last_json)
 
+    def test_last_crash_centos_7_7(self):
+        """
+        Test plain 'last' on Centos 7.7 with crash entries
+        """
+        self.assertEqual(jc.parsers.last.parse(self.centos_7_7_last_crash, quiet=True), self.centos_7_7_last_crash_json)
+
+    # Run this test locally only since environment differences can cause test failures
+    # def test_last_wF_centos_7_7(self):
+    #     """
+    #     Test 'last -wF' on Centos 7.7
+    #     """
+    #     self.assertEqual(jc.parsers.last.parse(self.centos_7_7_last_wF, quiet=True), self.centos_7_7_last_wF_json)
 
 if __name__ == '__main__':
     unittest.main()
